@@ -83,17 +83,39 @@ class GroundTruthData(Dataset, StateSpace):
 
     @property
     def observation_shape(self) -> Tuple[int, ...]:
+        # TODO: deprecate this!
+        # TODO: observation_shape should be called img_shape
         # shape as would be for a non-batched observation
         # eg. H x W x C
         raise NotImplementedError()
 
     @property
     def x_shape(self) -> Tuple[int, ...]:
+        # TODO: deprecate this!
+        # TODO: x_shape should be called obs_shape
         # shape as would be for a single observation in a torch batch
         # eg. C x H x W
         shape = self.observation_shape
         return shape[-1], *shape[:-1]
 
+    @property
+    def img_shape(self) -> Tuple[int, ...]:
+        # shape as would be for an original image
+        # eg. H x W x C
+        return self.observation_shape
+
+    @property
+    def obs_shape(self) -> Tuple[int, ...]:
+        # shape as would be for a single observation in a torch batch
+        # eg. C x H x W
+        return self.x_shape
+
+    @property
+    def img_channels(self) -> int:
+        channels = self.img_shape[-1]
+        assert channels in (1, 3), f'invalid number of channels for dataset: {self.__class__.__name__}, got: {repr(channels)}, required: 1 or 3'
+        return channels
+
     def __getitem__(self, idx):
         obs = self._get_observation(idx)
         if self._transform is not None:
@@ -127,14 +149,27 @@ class GroundTruthData(Dataset, StateSpace):
 
 class ArrayGroundTruthData(GroundTruthData):
 
-    def __init__(self, array, factor_names: Tuple[str, ...], factor_sizes: Tuple[int, ...], observation_shape: Optional[Tuple[int, ...]] = None, transform=None):
+    def __init__(self, array, factor_names: Tuple[str, ...], factor_sizes: Tuple[int, ...], array_chn_is_last: bool = True, observation_shape: Optional[Tuple[int, ...]] = None, transform=None):
         self.__factor_names = tuple(factor_names)
         self.__factor_sizes = tuple(factor_sizes)
-        print(array.shape)
-        self.__observation_shape = tuple(observation_shape if (observation_shape is not None) else array.shape[1:])
         self._array = array
+        # get shape
+        if observation_shape is not None:
+            C, H, W = observation_shape
+        elif array_chn_is_last:
+            H, W, C = array.shape[1:]
+        else:
+            C, H, W = array.shape[1:]
+        # set observation shape
+        self.__observation_shape = (H, W, C)
         # initialize
         super().__init__(transform=transform)
+        # check shapes -- it is up to the user to handle which method they choose
+        assert (array.shape[1:] == self.img_shape) or (array.shape[1:] == self.obs_shape)
+
+    @property
+    def array(self):
+        return self._array
 
     @property
     def factor_names(self) -> Tuple[str, ...]:
@@ -149,18 +184,22 @@ class ArrayGroundTruthData(GroundTruthData):
         return self.__observation_shape
 
     def _get_observation(self, idx):
+        # TODO: INVESTIGATE! I think this implements a lock,
+        #       hindering multi-threaded environments?
         return self._array[idx]
 
     @classmethod
-    def new_like(cls, array, dataset: GroundTruthData):
+    def new_like(cls, array, dataset: GroundTruthData, array_chn_is_last: bool = True):
         return cls(
             array=array,
             factor_names=dataset.factor_names,
             factor_sizes=dataset.factor_sizes,
+            array_chn_is_last=array_chn_is_last,
             observation_shape=None,  # infer from array
             transform=None,
         )
 
+
 # ========================================================================= #
 # disk ground truth data                                                    #
 # TODO: data & datafile preparation should be split out from                #
@@ -241,22 +280,23 @@ class NumpyFileGroundTruthData(DiskGroundTruthData, metaclass=ABCMeta):
         return None
 
 
-class Hdf5GroundTruthData(DiskGroundTruthData, metaclass=ABCMeta):
-    """
-    Dataset that loads an Hdf5 file from a DataObject
-    - requires that the data object has the `out_dataset_name` attribute
-      that points to the hdf5 dataset in the file to load.
-    """
+class _Hdf5DataMixin(object):
 
-    def __init__(self, data_root: Optional[str] = None, prepare: bool = False, in_memory=False, transform=None):
-        super().__init__(data_root=data_root, prepare=prepare, transform=transform)
+    # set attributes if _mixin_hdf5_init is called
+    _in_memory: bool
+    _attrs: dict
+    _data: Union[Hdf5Dataset, np.ndarray]
+
+    def _mixin_hdf5_init(self, h5_path: str, h5_dataset_name: str = 'data', in_memory: bool = False):
         # variables
         self._in_memory = in_memory
         # load the h5py dataset
         data = Hdf5Dataset(
-            h5_path=os.path.join(self.data_dir, self.datafile.out_name),
-            h5_dataset_name=self.datafile.dataset_name,
+            h5_path=h5_path,
+            h5_dataset_name=h5_dataset_name,
         )
+        # load attributes
+        self._attrs = data.get_attrs()
         # handle different memory modes
         if self._in_memory:
             # Load the entire dataset into memory if required
@@ -268,9 +308,27 @@ class Hdf5GroundTruthData(DiskGroundTruthData, metaclass=ABCMeta):
             # Load the dataset from the disk
             self._data = data
 
+    # override from GroundTruthData
     def _get_observation(self, idx):
         return self._data[idx]
 
+
+class Hdf5GroundTruthData(_Hdf5DataMixin, DiskGroundTruthData, metaclass=ABCMeta):
+    """
+    Dataset that loads an Hdf5 file from a DataObject
+    - requires that the data object has the `out_dataset_name` attribute
+      that points to the hdf5 dataset in the file to load.
+    """
+
+    def __init__(self, data_root: Optional[str] = None, prepare: bool = False, in_memory=False, transform=None):
+        super().__init__(data_root=data_root, prepare=prepare, transform=transform)
+        # initialize mixin
+        self._mixin_hdf5_init(
+            h5_path=os.path.join(self.data_dir, self.datafile.out_name),
+            h5_dataset_name=self.datafile.dataset_name,
+            in_memory=in_memory,
+        )
+
     @property
     def datafiles(self) -> Sequence[DataFileHashedDlH5]:
         return [self.datafile]
@@ -280,6 +338,42 @@ class Hdf5GroundTruthData(DiskGroundTruthData, metaclass=ABCMeta):
         raise NotImplementedError
 
 
+class SelfContainedHdf5GroundTruthData(_Hdf5DataMixin, GroundTruthData):
+
+    def __init__(self, h5_path: str, in_memory=False, transform=None):
+        # initialize mixin
+        self._mixin_hdf5_init(
+            h5_path=h5_path,
+            h5_dataset_name='data',
+            in_memory=in_memory,
+        )
+        # load attrs
+        self._attr_name = self._attrs['dataset_name'].decode("utf-8")
+        self._attr_factor_names = tuple(name.decode("utf-8") for name in self._attrs['factor_names'])
+        self._attr_factor_sizes = tuple(int(size) for size in self._attrs['factor_sizes'])
+        # set size
+        (B, H, W, C) = self._data.shape
+        self._observation_shape = (H, W, C)
+        # initialize!
+        super().__init__(transform=transform)
+
+    @property
+    def name(self) -> str:
+        return self._attr_name
+
+    @property
+    def factor_names(self) -> Tuple[str, ...]:
+        return self._attr_factor_names
+
+    @property
+    def factor_sizes(self) -> Tuple[int, ...]:
+        return self._attr_factor_sizes
+
+    @property
+    def observation_shape(self) -> Tuple[int, ...]:
+        return self._observation_shape
+
+
 # ========================================================================= #
 # END                                                                       #
 # ========================================================================= #
