@@ -22,6 +22,7 @@
 #  SOFTWARE.
 #  ~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~
 
+import logging
 import hydra
 import torch.utils.data
 import pytorch_lightning as pl
@@ -32,6 +33,9 @@ from disent.nn.transform import DisentDatasetTransform
 from experiment.util.hydra_utils import instantiate_recursive
 
 
+log = logging.getLogger(__name__)
+
+
 # ========================================================================= #
 # DISENT DATASET MODULE                                                     #
 # TODO: possible implementation outline for disent                          #
@@ -80,9 +84,9 @@ class HydraDataModule(pl.LightningDataModule):
         super().__init__()
         # support pytorch lightning < 1.4
         if not hasattr(self, 'hparams'):
-            self.hparams = {}
-        # set values
-        self.hparams.update(hparams)
+            self.hparams = DictConfig(hparams)
+        else:
+            self.hparams.update(hparams)
         # transform: prepares data from datasets
         self.data_transform = instantiate_recursive(self.hparams.dataset.transform)
         assert (self.data_transform is None) or callable(self.data_transform)
@@ -108,18 +112,21 @@ class HydraDataModule(pl.LightningDataModule):
         data = dict(self.hparams.dataset.data)
         if 'in_memory' in data:
             del data['in_memory']
+        # create the data
+        # - we instantiate the data twice, once here and once in setup otherwise
+        #   things could go wrong. We try be efficient about it by removing the
+        #   in_memory argument if it exists.
+        log.info(f'Data - Preparation & Downloading')
         instantiate_recursive(data)
 
     def setup(self, stage=None) -> None:
         # ground truth data
+        log.info(f'Data - Instance')
         data = instantiate_recursive(self.hparams.dataset.data)
         # Wrap the data for the framework some datasets need triplets, pairs, etc.
         # Augmentation is done inside the frameworks so that it can be done on the GPU, otherwise things are very slow.
         self.dataset_train_noaug = DisentDataset(data, hydra.utils.instantiate(self.hparams.dataset_sampler.sampler), transform=self.data_transform, augment=None)
         self.dataset_train_aug = DisentDataset(data, hydra.utils.instantiate(self.hparams.dataset_sampler.sampler), transform=self.data_transform, augment=self.input_transform)
-        # TODO: make these assertions more general with some base-class
-        assert isinstance(self.dataset_train_noaug, DisentDataset)
-        assert isinstance(self.dataset_train_aug, DisentDataset)
 
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
     # Training Dataset:
